@@ -233,6 +233,9 @@ void MainWindow::connectTools()
     QObject::connect(ui->colorBoxWidget, &ColorBoxWidget::primaryColorChanged, LINE_TOOL, &LineTool::setPrimaryColor);
     QObject::connect(ui->colorBoxWidget, &ColorBoxWidget::secondaryColorChanged, LINE_TOOL, &LineTool::setSecondaryColor);
 
+    ERASER_TOOL->setSecondaryColor(ui->colorBoxWidget->secondaryColor());
+    QObject::connect(ui->colorBoxWidget, &ColorBoxWidget::secondaryColorChanged, ERASER_TOOL, &EraserTool::setSecondaryColor);
+
     // Connect PointerTool signals
     QObject::connect(MOUSE_POINTER, SIGNAL(crop(const QRect&)), this, SLOT(onCrop(const QRect&)));
     QObject::connect(MOUSE_POINTER, SIGNAL(save()), this, SLOT(on_actionSave_triggered()));
@@ -384,22 +387,24 @@ void MainWindow::on_actionNew_triggered()
 void MainWindow::on_actionOpen_triggered()
 {
     const QStringList& fileName = QFileDialog::getOpenFileNames(this, tr("Open File"),
-    SETTINGS->getOpenFolder(), tr("Image Files (*.png *.jpg *.jpeg *.gif *.tif *.tiff *.bmp *.ico);;"
-                                "PNG(*.png);;"
-                                "JPEG(*.jpg *.jpeg);;"
-                                "GIF(*.gif);;"
-                                "TIFF(*.tif *.tiff);;"
-                                "BMP(*.bmp);;"
-                                "ICO(*.ico);;"
-                                "All Files (*)"));
+    SETTINGS->getOpenFolder(),
+    tr("Image Files")+"(*.png *.PNG *.jpg *.jpeg *.JPG *.JPEG *.gif *.GIF *.tif *.tiff *.TIF *.TIFF *.bmp *.BMP *.ico *.ICO);;"
+    "PNG(*.png *.PNG);;"
+    "JPEG(*.jpg *.jpeg *.JPG *.JPEG);;"
+    "GIF(*.gif *.GIF);;"
+    "TIFF(*.tif *.tiff *.TIF *.TIFF);;"
+    "BMP(*.bmp *.BMP);;"
+    "ICO(*.ico *.ICO);;"
+    +tr("All Files")+"(*)");
 /*
-                                "ARW (*.arw *.srf *.sr2);;"
-                                "BAY (*.bay);;"
-                                "CR2 (*.crw *.cr2);;"
-                                "DCS (*.dcs *.dcr *.drf *.k25 *.kdc);;"
-                                "MOS (*.mos);;"
-                                "NEF (*.nef *.nrw);;"
-                                "RAW (*.raw *.rw2)"));
+ *  Previously supported RAW formats
+    "ARW (*.arw *.srf *.sr2);;"
+    "BAY (*.bay);;"
+    "CR2 (*.crw *.cr2);;"
+    "DCS (*.dcs *.dcr *.drf *.k25 *.kdc);;"
+    "MOS (*.mos);;"
+    "NEF (*.nef *.nrw);;"
+    "RAW (*.raw *.rw2)"));
 */
 
     if(fileName.length()>0)
@@ -425,6 +430,7 @@ bool MainWindow::fileTypeSupported(QList<QByteArray> formats, QString ext)
         if(formats[i] == ext)
         {
             status = true;
+            break;
         }
     }
     return status;
@@ -437,7 +443,8 @@ QString MainWindow::prepareFile(const QString& fileName)
     QImageReader reader(fileName);
     reader.setDecideFormatFromContent(true); // Autodetect file type without depending on extension
 
-    if(info.completeSuffix().toLower() != "jpg" && info.completeSuffix() != reader.format() && fileTypeSupported(reader.supportedImageFormats(),reader.format()))
+    // Show warning if file type is supported but extension does not match
+    if(info.completeSuffix().toLower() != "jpg" && info.completeSuffix().toLower() != reader.format() && fileTypeSupported(reader.supportedImageFormats(),reader.format()))
     {
         int ret = QMessageBox::warning(this,
                     tr("Incorrect file extension detected"),
@@ -1027,7 +1034,7 @@ void MainWindow::on_actionTransparent_colour_triggered()
 
 void MainWindow::onTransparentFinished()
 {
-    delete transparentDialog;
+    transparentDialog = 0;
     // Restore previous tool
     m_toolSelected = m_previousToolSelected;
     QTimer::singleShot(1000, this, SLOT(refreshTools()));
@@ -1644,8 +1651,14 @@ void MainWindow::batchProcess_batchProgress(int index,int total)
 
 void MainWindow::on_actionPreferences_triggered()
 {
-    prefsDialog dialog(this);
-    dialog.exec();
+    prefsDialog = new PrefsDialog();
+    QObject::connect(prefsDialog, SIGNAL(safeQuitApp()), this, SLOT(onSafeQuitApp()));
+    prefsDialog->show();
+}
+
+void MainWindow::onSafeQuitApp()
+{
+    on_actionQuit_triggered();
 }
 
 void MainWindow::on_actionPlugins_triggered()
@@ -2219,8 +2232,16 @@ bool MainWindow::handleCloseChildWindow(QMdiSubWindow *subWindow)
             saveContent();
         }
     }
-
     subWindow->setWindowModified(false);
+
+    // Clear Undo History just before we close the tab
+    PaintWidget *widget = getCurrentPaintWidget();
+    if (widget)
+    {
+        widget->clearUndoHistory();
+        ui->actionUndo->setEnabled(widget->isUndoEnabled());
+        ui->actionRedo->setEnabled(widget->isRedoEnabled());
+    }
     subWindow->close();
 
     clearStatusArea();
