@@ -29,7 +29,7 @@ class PointerSettingsWidget : public QWidget
     Q_OBJECT
 
 public:
-    explicit PointerSettingsWidget(QWidget *parent = 0);
+    explicit PointerSettingsWidget(QWidget *parent = nullptr);
     ~PointerSettingsWidget();
 
     bool stroke() const;
@@ -38,6 +38,10 @@ public:
 signals:
     void settingsChanged();
 
+private slots:
+    void on_square_sel_clicked(bool checked);
+    void on_circle_sel_clicked(bool checked);
+
 private:
     Ui::PointerSettingsWidget *ui;
 };
